# this file is @generated
from .aggregate_event_types_out import AggregateEventTypesOut
from .app_portal_access_in import AppPortalAccessIn
from .app_portal_access_out import AppPortalAccessOut
from .app_usage_stats_in import AppUsageStatsIn
from .app_usage_stats_out import AppUsageStatsOut
from .application_in import ApplicationIn
from .application_out import ApplicationOut
from .application_patch import ApplicationPatch
from .application_token_expire_in import ApplicationTokenExpireIn
from .background_task_data import BackgroundTaskData
from .background_task_out import BackgroundTaskOut
from .background_task_status import BackgroundTaskStatus
from .background_task_type import BackgroundTaskType
from .dashboard_access_out import DashboardAccessOut
from .endpoint_headers_in import EndpointHeadersIn
from .endpoint_headers_out import EndpointHeadersOut
from .endpoint_headers_patch_in import EndpointHeadersPatchIn
from .endpoint_in import EndpointIn
from .endpoint_message_out import EndpointMessageOut
from .endpoint_out import EndpointOut
from .endpoint_patch import EndpointPatch
from .endpoint_secret_out import EndpointSecretOut
from .endpoint_secret_rotate_in import EndpointSecretRotateIn
from .endpoint_stats import EndpointStats
from .endpoint_transformation_in import EndpointTransformationIn
from .endpoint_transformation_out import EndpointTransformationOut
from .endpoint_update import EndpointUpdate
from .environment_in import EnvironmentIn
from .environment_out import EnvironmentOut
from .event_example_in import EventExampleIn
from .event_type_from_open_api import EventTypeFromOpenApi
from .event_type_import_open_api_in import EventTypeImportOpenApiIn
from .event_type_import_open_api_out import EventTypeImportOpenApiOut
from .event_type_import_open_api_out_data import EventTypeImportOpenApiOutData
from .event_type_in import EventTypeIn
from .event_type_out import EventTypeOut
from .event_type_patch import EventTypePatch
from .event_type_update import EventTypeUpdate
from .integration_in import IntegrationIn
from .integration_key_out import IntegrationKeyOut
from .integration_out import IntegrationOut
from .integration_update import IntegrationUpdate
from .list_response_application_out import ListResponseApplicationOut
from .list_response_background_task_out import ListResponseBackgroundTaskOut
from .list_response_endpoint_message_out import ListResponseEndpointMessageOut
from .list_response_endpoint_out import ListResponseEndpointOut
from .list_response_event_type_out import ListResponseEventTypeOut
from .list_response_integration_out import ListResponseIntegrationOut
from .list_response_message_attempt_out import ListResponseMessageAttemptOut
from .list_response_message_endpoint_out import ListResponseMessageEndpointOut
from .list_response_message_out import ListResponseMessageOut
from .list_response_operational_webhook_endpoint_out import (
    ListResponseOperationalWebhookEndpointOut,
)
from .message_attempt_out import MessageAttemptOut
from .message_attempt_trigger_type import MessageAttemptTriggerType
from .message_endpoint_out import MessageEndpointOut
from .message_in import MessageIn
from .message_out import MessageOut
from .message_status import MessageStatus
from .operational_webhook_endpoint_headers_in import OperationalWebhookEndpointHeadersIn
from .operational_webhook_endpoint_headers_out import (
    OperationalWebhookEndpointHeadersOut,
)
from .operational_webhook_endpoint_in import OperationalWebhookEndpointIn
from .operational_webhook_endpoint_out import OperationalWebhookEndpointOut
from .operational_webhook_endpoint_secret_in import OperationalWebhookEndpointSecretIn
from .operational_webhook_endpoint_secret_out import OperationalWebhookEndpointSecretOut
from .operational_webhook_endpoint_update import OperationalWebhookEndpointUpdate
from .ordering import Ordering
from .recover_in import RecoverIn
from .recover_out import RecoverOut
from .replay_in import ReplayIn
from .replay_out import ReplayOut
from .status_code_class import StatusCodeClass
from .template_in import TemplateIn
from .template_out import TemplateOut
from .transformation_template_kind import TransformationTemplateKind

__all__ = [
    "BackgroundTaskData",
    "AggregateEventTypesOut",
    "AppPortalAccessIn",
    "AppPortalAccessOut",
    "AppUsageStatsIn",
    "AppUsageStatsOut",
    "ApplicationIn",
    "ApplicationOut",
    "ApplicationPatch",
    "ApplicationTokenExpireIn",
    "BackgroundTaskOut",
    "BackgroundTaskStatus",
    "BackgroundTaskType",
    "DashboardAccessOut",
    "EndpointHeadersIn",
    "EndpointHeadersOut",
    "EndpointHeadersPatchIn",
    "EndpointIn",
    "EndpointMessageOut",
    "EndpointOut",
    "EndpointPatch",
    "EndpointSecretOut",
    "EndpointSecretRotateIn",
    "EndpointStats",
    "EndpointTransformationIn",
    "EndpointTransformationOut",
    "EndpointUpdate",
    "EnvironmentIn",
    "EnvironmentOut",
    "EventExampleIn",
    "EventTypeFromOpenApi",
    "EventTypeImportOpenApiIn",
    "EventTypeImportOpenApiOut",
    "EventTypeImportOpenApiOutData",
    "EventTypeIn",
    "EventTypeOut",
    "EventTypePatch",
    "EventTypeUpdate",
    "IntegrationIn",
    "IntegrationKeyOut",
    "IntegrationOut",
    "IntegrationUpdate",
    "ListResponseApplicationOut",
    "ListResponseBackgroundTaskOut",
    "ListResponseEndpointMessageOut",
    "ListResponseEndpointOut",
    "ListResponseEventTypeOut",
    "ListResponseIntegrationOut",
    "ListResponseMessageAttemptOut",
    "ListResponseMessageEndpointOut",
    "ListResponseMessageOut",
    "ListResponseOperationalWebhookEndpointOut",
    "MessageAttemptOut",
    "MessageAttemptTriggerType",
    "MessageEndpointOut",
    "MessageIn",
    "MessageOut",
    "MessageStatus",
    "OperationalWebhookEndpointHeadersIn",
    "OperationalWebhookEndpointHeadersOut",
    "OperationalWebhookEndpointIn",
    "OperationalWebhookEndpointOut",
    "OperationalWebhookEndpointSecretIn",
    "OperationalWebhookEndpointSecretOut",
    "OperationalWebhookEndpointUpdate",
    "Ordering",
    "RecoverIn",
    "RecoverOut",
    "ReplayIn",
    "ReplayOut",
    "StatusCodeClass",
    "TemplateIn",
    "TemplateOut",
    "TransformationTemplateKind",
]



# this file is @generated
from enum import IntEnum


class MessageAttemptTriggerType(IntEnum):
    """The reason an attempt was made:
    - Scheduled = 0
    - Manual = 1"""

    SCHEDULED = 0
    MANUAL = 1

    def __str__(self) -> str:
        return str(self.value)



# this file is @generated

from .common import BaseModel
from .event_type_import_open_api_out_data import EventTypeImportOpenApiOutData


class EventTypeImportOpenApiOut(BaseModel):
    data: EventTypeImportOpenApiOutData



# This file is @generated
import typing as t
from dataclasses import dataclass
from datetime import datetime

from .. import models
from ..models import (
    ListResponseEndpointMessageOut,
    ListResponseMessageAttemptOut,
    ListResponseMessageEndpointOut,
    MessageAttemptOut,
)
from .common import ApiBase, BaseOptions, serialize_params


@dataclass
class MessageAttemptListByEndpointOptions(BaseOptions):
    limit: t.Optional[int] = None
    """Limit the number of returned items"""
    iterator: t.Optional[str] = None
    """The iterator returned from a prior invocation"""
    status: t.Optional[models.MessageStatus] = None
    """Filter response based on the status of the attempt: Success (0), Pending (1), Failed (2), or Sending (3)"""
    status_code_class: t.Optional[models.StatusCodeClass] = None
    """Filter response based on the HTTP status code"""
    channel: t.Optional[str] = None
    """Filter response based on the channel"""
    tag: t.Optional[str] = None
    """Filter response based on the tag"""
    before: t.Optional[datetime] = None
    """Only include items created before a certain date"""
    after: t.Optional[datetime] = None
    """Only include items created after a certain date"""
    with_content: t.Optional[bool] = None
    """When `true` attempt content is included in the response"""
    with_msg: t.Optional[bool] = None
    """When `true`, the message information is included in the response"""
    event_types: t.Optional[t.List[str]] = None
    """Filter response based on the event type"""

    def _query_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "limit": self.limit,
                "iterator": self.iterator,
                "status": self.status,
                "status_code_class": self.status_code_class,
                "channel": self.channel,
                "tag": self.tag,
                "before": self.before,
                "after": self.after,
                "with_content": self.with_content,
                "with_msg": self.with_msg,
                "event_types": self.event_types,
            }
        )


@dataclass
class MessageAttemptListByMsgOptions(BaseOptions):
    limit: t.Optional[int] = None
    """Limit the number of returned items"""
    iterator: t.Optional[str] = None
    """The iterator returned from a prior invocation"""
    status: t.Optional[models.MessageStatus] = None
    """Filter response based on the status of the attempt: Success (0), Pending (1), Failed (2), or Sending (3)"""
    status_code_class: t.Optional[models.StatusCodeClass] = None
    """Filter response based on the HTTP status code"""
    channel: t.Optional[str] = None
    """Filter response based on the channel"""
    tag: t.Optional[str] = None
    """Filter response based on the tag"""
    endpoint_id: t.Optional[str] = None
    """Filter the attempts based on the attempted endpoint"""
    before: t.Optional[datetime] = None
    """Only include items created before a certain date"""
    after: t.Optional[datetime] = None
    """Only include items created after a certain date"""
    with_content: t.Optional[bool] = None
    """When `true` attempt content is included in the response"""
    event_types: t.Optional[t.List[str]] = None
    """Filter response based on the event type"""

    def _query_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "limit": self.limit,
                "iterator": self.iterator,
                "status": self.status,
                "status_code_class": self.status_code_class,
                "channel": self.channel,
                "tag": self.tag,
                "endpoint_id": self.endpoint_id,
                "before": self.before,
                "after": self.after,
                "with_content": self.with_content,
                "event_types": self.event_types,
            }
        )


@dataclass
class MessageAttemptListAttemptedMessagesOptions(BaseOptions):
    limit: t.Optional[int] = None
    """Limit the number of returned items"""
    iterator: t.Optional[str] = None
    """The iterator returned from a prior invocation"""
    channel: t.Optional[str] = None
    """Filter response based on the channel"""
    tag: t.Optional[str] = None
    """Filter response based on the message tags"""
    status: t.Optional[models.MessageStatus] = None
    """Filter response based on the status of the attempt: Success (0), Pending (1), Failed (2), or Sending (3)"""
    before: t.Optional[datetime] = None
    """Only include items created before a certain date"""
    after: t.Optional[datetime] = None
    """Only include items created after a certain date"""
    with_content: t.Optional[bool] = None
    """When `true` message payloads are included in the response"""
    event_types: t.Optional[t.List[str]] = None
    """Filter response based on the event type"""

    def _query_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "limit": self.limit,
                "iterator": self.iterator,
                "channel": self.channel,
                "tag": self.tag,
                "status": self.status,
                "before": self.before,
                "after": self.after,
                "with_content": self.with_content,
                "event_types": self.event_types,
            }
        )


@dataclass
class MessageAttemptListAttemptedDestinationsOptions(BaseOptions):
    limit: t.Optional[int] = None
    """Limit the number of returned items"""
    iterator: t.Optional[str] = None
    """The iterator returned from a prior invocation"""

    def _query_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "limit": self.limit,
                "iterator": self.iterator,
            }
        )


@dataclass
class MessageAttemptResendOptions(BaseOptions):
    idempotency_key: t.Optional[str] = None

    def _header_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "idempotency-key": self.idempotency_key,
            }
        )


class MessageAttemptAsync(ApiBase):
    async def list_by_endpoint(
        self,
        app_id: str,
        endpoint_id: str,
        options: MessageAttemptListByEndpointOptions = MessageAttemptListByEndpointOptions(),
    ) -> ListResponseMessageAttemptOut:
        """List attempts by endpoint id

        Note that by default this endpoint is limited to retrieving 90 days' worth of data
        relative to now or, if an iterator is provided, 90 days before/after the time indicated
        by the iterator ID. If you require data beyond those time ranges, you will need to explicitly
        set the `before` or `after` parameter as appropriate.
        """
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/app/{app_id}/attempt/endpoint/{endpoint_id}",
            path_params={
                "app_id": app_id,
                "endpoint_id": endpoint_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseMessageAttemptOut.model_validate(response.json())

    async def list_by_msg(
        self,
        app_id: str,
        msg_id: str,
        options: MessageAttemptListByMsgOptions = MessageAttemptListByMsgOptions(),
    ) -> ListResponseMessageAttemptOut:
        """List attempts by message ID.

        Note that by default this endpoint is limited to retrieving 90 days' worth of data
        relative to now or, if an iterator is provided, 90 days before/after the time indicated
        by the iterator ID. If you require data beyond those time ranges, you will need to explicitly
        set the `before` or `after` parameter as appropriate."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/app/{app_id}/attempt/msg/{msg_id}",
            path_params={
                "app_id": app_id,
                "msg_id": msg_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseMessageAttemptOut.model_validate(response.json())

    async def list_attempted_messages(
        self,
        app_id: str,
        endpoint_id: str,
        options: MessageAttemptListAttemptedMessagesOptions = MessageAttemptListAttemptedMessagesOptions(),
    ) -> ListResponseEndpointMessageOut:
        """List messages for a particular endpoint. Additionally includes metadata about the latest message attempt.

        The `before` parameter lets you filter all items created before a certain date and is ignored if an iterator is passed.

        Note that by default this endpoint is limited to retrieving 90 days' worth of data
        relative to now or, if an iterator is provided, 90 days before/after the time indicated
        by the iterator ID. If you require data beyond those time ranges, you will need to explicitly
        set the `before` or `after` parameter as appropriate.
        """
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/app/{app_id}/endpoint/{endpoint_id}/msg",
            path_params={
                "app_id": app_id,
                "endpoint_id": endpoint_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseEndpointMessageOut.model_validate(response.json())

    async def get(self, app_id: str, msg_id: str, attempt_id: str) -> MessageAttemptOut:
        """`msg_id`: Use a message id or a message `eventId`"""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/app/{app_id}/msg/{msg_id}/attempt/{attempt_id}",
            path_params={
                "app_id": app_id,
                "msg_id": msg_id,
                "attempt_id": attempt_id,
            },
        )
        return MessageAttemptOut.model_validate(response.json())

    async def expunge_content(self, app_id: str, msg_id: str, attempt_id: str) -> None:
        """Deletes the given attempt's response body.

        Useful when an endpoint accidentally returned sensitive content.
        The message can't be replayed or resent once its payload has been deleted or expired."""
        await self._request_asyncio(
            method="delete",
            path="/api/v1/app/{app_id}/msg/{msg_id}/attempt/{attempt_id}/content",
            path_params={
                "app_id": app_id,
                "msg_id": msg_id,
                "attempt_id": attempt_id,
            },
        )

    async def list_attempted_destinations(
        self,
        app_id: str,
        msg_id: str,
        options: MessageAttemptListAttemptedDestinationsOptions = MessageAttemptListAttemptedDestinationsOptions(),
    ) -> ListResponseMessageEndpointOut:
        """List endpoints attempted by a given message.

        Additionally includes metadata about the latest message attempt.
        By default, endpoints are listed in ascending order by ID."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/app/{app_id}/msg/{msg_id}/endpoint",
            path_params={
                "app_id": app_id,
                "msg_id": msg_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseMessageEndpointOut.model_validate(response.json())

    async def resend(
        self,
        app_id: str,
        msg_id: str,
        endpoint_id: str,
        options: MessageAttemptResendOptions = MessageAttemptResendOptions(),
    ) -> None:
        """Resend a message to the specified endpoint."""
        await self._request_asyncio(
            method="post",
            path="/api/v1/app/{app_id}/msg/{msg_id}/endpoint/{endpoint_id}/resend",
            path_params={
                "app_id": app_id,
                "msg_id": msg_id,
                "endpoint_id": endpoint_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )


class MessageAttempt(ApiBase):
    def list_by_endpoint(
        self,
        app_id: str,
        endpoint_id: str,
        options: MessageAttemptListByEndpointOptions = MessageAttemptListByEndpointOptions(),
    ) -> ListResponseMessageAttemptOut:
        """List attempts by endpoint id

        Note that by default this endpoint is limited to retrieving 90 days' worth of data
        relative to now or, if an iterator is provided, 90 days before/after the time indicated
        by the iterator ID. If you require data beyond those time ranges, you will need to explicitly
        set the `before` or `after` parameter as appropriate.
        """
        response = self._request_sync(
            method="get",
            path="/api/v1/app/{app_id}/attempt/endpoint/{endpoint_id}",
            path_params={
                "app_id": app_id,
                "endpoint_id": endpoint_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseMessageAttemptOut.model_validate(response.json())

    def list_by_msg(
        self,
        app_id: str,
        msg_id: str,
        options: MessageAttemptListByMsgOptions = MessageAttemptListByMsgOptions(),
    ) -> ListResponseMessageAttemptOut:
        """List attempts by message ID.

        Note that by default this endpoint is limited to retrieving 90 days' worth of data
        relative to now or, if an iterator is provided, 90 days before/after the time indicated
        by the iterator ID. If you require data beyond those time ranges, you will need to explicitly
        set the `before` or `after` parameter as appropriate."""
        response = self._request_sync(
            method="get",
            path="/api/v1/app/{app_id}/attempt/msg/{msg_id}",
            path_params={
                "app_id": app_id,
                "msg_id": msg_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseMessageAttemptOut.model_validate(response.json())

    def list_attempted_messages(
        self,
        app_id: str,
        endpoint_id: str,
        options: MessageAttemptListAttemptedMessagesOptions = MessageAttemptListAttemptedMessagesOptions(),
    ) -> ListResponseEndpointMessageOut:
        """List messages for a particular endpoint. Additionally includes metadata about the latest message attempt.

        The `before` parameter lets you filter all items created before a certain date and is ignored if an iterator is passed.

        Note that by default this endpoint is limited to retrieving 90 days' worth of data
        relative to now or, if an iterator is provided, 90 days before/after the time indicated
        by the iterator ID. If you require data beyond those time ranges, you will need to explicitly
        set the `before` or `after` parameter as appropriate.
        """
        response = self._request_sync(
            method="get",
            path="/api/v1/app/{app_id}/endpoint/{endpoint_id}/msg",
            path_params={
                "app_id": app_id,
                "endpoint_id": endpoint_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseEndpointMessageOut.model_validate(response.json())

    def get(self, app_id: str, msg_id: str, attempt_id: str) -> MessageAttemptOut:
        """`msg_id`: Use a message id or a message `eventId`"""
        response = self._request_sync(
            method="get",
            path="/api/v1/app/{app_id}/msg/{msg_id}/attempt/{attempt_id}",
            path_params={
                "app_id": app_id,
                "msg_id": msg_id,
                "attempt_id": attempt_id,
            },
        )
        return MessageAttemptOut.model_validate(response.json())

    def expunge_content(self, app_id: str, msg_id: str, attempt_id: str) -> None:
        """Deletes the given attempt's response body.

        Useful when an endpoint accidentally returned sensitive content.
        The message can't be replayed or resent once its payload has been deleted or expired."""
        self._request_sync(
            method="delete",
            path="/api/v1/app/{app_id}/msg/{msg_id}/attempt/{attempt_id}/content",
            path_params={
                "app_id": app_id,
                "msg_id": msg_id,
                "attempt_id": attempt_id,
            },
        )

    def list_attempted_destinations(
        self,
        app_id: str,
        msg_id: str,
        options: MessageAttemptListAttemptedDestinationsOptions = MessageAttemptListAttemptedDestinationsOptions(),
    ) -> ListResponseMessageEndpointOut:
        """List endpoints attempted by a given message.

        Additionally includes metadata about the latest message attempt.
        By default, endpoints are listed in ascending order by ID."""
        response = self._request_sync(
            method="get",
            path="/api/v1/app/{app_id}/msg/{msg_id}/endpoint",
            path_params={
                "app_id": app_id,
                "msg_id": msg_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseMessageEndpointOut.model_validate(response.json())

    def resend(
        self,
        app_id: str,
        msg_id: str,
        endpoint_id: str,
        options: MessageAttemptResendOptions = MessageAttemptResendOptions(),
    ) -> None:
        """Resend a message to the specified endpoint."""
        self._request_sync(
            method="post",
            path="/api/v1/app/{app_id}/msg/{msg_id}/endpoint/{endpoint_id}/resend",
            path_params={
                "app_id": app_id,
                "msg_id": msg_id,
                "endpoint_id": endpoint_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )



# this file is @generated
import typing as t

from .common import BaseModel
from .event_type_in import EventTypeIn
from .template_in import TemplateIn


class EnvironmentIn(BaseModel):
    event_types: t.Optional[t.List[EventTypeIn]] = None

    settings: t.Optional[t.Dict[str, t.Any]] = None

    transformation_templates: t.Optional[t.List[TemplateIn]] = None



# this file is @generated
import typing as t
from datetime import datetime

from .common import BaseModel


class MessageOut(BaseModel):
    channels: t.Optional[t.List[str]] = None
    """List of free-form identifiers that endpoints can filter by"""

    event_id: t.Optional[str] = None
    """Optional unique identifier for the message"""

    event_type: str
    """The event type's name"""

    id: str
    """The msg's ID"""

    payload: t.Dict[str, t.Any]

    tags: t.Optional[t.List[str]] = None

    timestamp: datetime



# this file is @generated
import typing as t

from .common import BaseModel


class EndpointUpdate(BaseModel):
    channels: t.Optional[t.List[str]] = None
    """List of message channels this endpoint listens to (omit for all)."""

    description: t.Optional[str] = None

    disabled: t.Optional[bool] = None

    filter_types: t.Optional[t.List[str]] = None

    metadata: t.Optional[t.Dict[str, str]] = None

    rate_limit: t.Optional[int] = None

    uid: t.Optional[str] = None
    """Optional unique identifier for the endpoint."""

    url: str

    version: t.Optional[int] = None



# this file is @generated
import typing as t
from datetime import datetime

from .common import BaseModel


class OperationalWebhookEndpointOut(BaseModel):
    created_at: datetime

    description: str
    """An example endpoint name."""

    disabled: t.Optional[bool] = None

    filter_types: t.Optional[t.List[str]] = None

    id: str
    """The ep's ID"""

    metadata: t.Dict[str, str]

    rate_limit: t.Optional[int] = None

    uid: t.Optional[str] = None
    """Optional unique identifier for the endpoint."""

    updated_at: datetime

    url: str



# This file is @generated
import typing as t
from dataclasses import dataclass

from .. import models
from ..models import (
    ListResponseOperationalWebhookEndpointOut,
    OperationalWebhookEndpointHeadersIn,
    OperationalWebhookEndpointHeadersOut,
    OperationalWebhookEndpointIn,
    OperationalWebhookEndpointOut,
    OperationalWebhookEndpointSecretIn,
    OperationalWebhookEndpointSecretOut,
    OperationalWebhookEndpointUpdate,
)
from .common import ApiBase, BaseOptions, serialize_params


@dataclass
class OperationalWebhookEndpointListOptions(BaseOptions):
    limit: t.Optional[int] = None
    """Limit the number of returned items"""
    iterator: t.Optional[str] = None
    """The iterator returned from a prior invocation"""
    order: t.Optional[models.Ordering] = None
    """The sorting order of the returned items"""

    def _query_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "limit": self.limit,
                "iterator": self.iterator,
                "order": self.order,
            }
        )


@dataclass
class OperationalWebhookEndpointCreateOptions(BaseOptions):
    idempotency_key: t.Optional[str] = None

    def _header_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "idempotency-key": self.idempotency_key,
            }
        )


@dataclass
class OperationalWebhookEndpointRotateSecretOptions(BaseOptions):
    idempotency_key: t.Optional[str] = None

    def _header_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "idempotency-key": self.idempotency_key,
            }
        )


class OperationalWebhookEndpointAsync(ApiBase):
    async def list(
        self,
        options: OperationalWebhookEndpointListOptions = OperationalWebhookEndpointListOptions(),
    ) -> ListResponseOperationalWebhookEndpointOut:
        """List operational webhook endpoints."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/operational-webhook/endpoint",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseOperationalWebhookEndpointOut.model_validate(response.json())

    async def create(
        self,
        operational_webhook_endpoint_in: OperationalWebhookEndpointIn,
        options: OperationalWebhookEndpointCreateOptions = OperationalWebhookEndpointCreateOptions(),
    ) -> OperationalWebhookEndpointOut:
        """Create an operational webhook endpoint."""
        response = await self._request_asyncio(
            method="post",
            path="/api/v1/operational-webhook/endpoint",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=operational_webhook_endpoint_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return OperationalWebhookEndpointOut.model_validate(response.json())

    async def get(self, endpoint_id: str) -> OperationalWebhookEndpointOut:
        """Get an operational webhook endpoint."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}",
            path_params={
                "endpoint_id": endpoint_id,
            },
        )
        return OperationalWebhookEndpointOut.model_validate(response.json())

    async def update(
        self,
        endpoint_id: str,
        operational_webhook_endpoint_update: OperationalWebhookEndpointUpdate,
    ) -> OperationalWebhookEndpointOut:
        """Update an operational webhook endpoint."""
        response = await self._request_asyncio(
            method="put",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}",
            path_params={
                "endpoint_id": endpoint_id,
            },
            json_body=operational_webhook_endpoint_update.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return OperationalWebhookEndpointOut.model_validate(response.json())

    async def delete(self, endpoint_id: str) -> None:
        """Delete an operational webhook endpoint."""
        await self._request_asyncio(
            method="delete",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}",
            path_params={
                "endpoint_id": endpoint_id,
            },
        )

    async def get_headers(
        self, endpoint_id: str
    ) -> OperationalWebhookEndpointHeadersOut:
        """Get the additional headers to be sent with the operational webhook."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}/headers",
            path_params={
                "endpoint_id": endpoint_id,
            },
        )
        return OperationalWebhookEndpointHeadersOut.model_validate(response.json())

    async def update_headers(
        self,
        endpoint_id: str,
        operational_webhook_endpoint_headers_in: OperationalWebhookEndpointHeadersIn,
    ) -> None:
        """Set the additional headers to be sent with the operational webhook."""
        await self._request_asyncio(
            method="put",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}/headers",
            path_params={
                "endpoint_id": endpoint_id,
            },
            json_body=operational_webhook_endpoint_headers_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )

    async def get_secret(self, endpoint_id: str) -> OperationalWebhookEndpointSecretOut:
        """Get an operational webhook endpoint's signing secret.

        This is used to verify the authenticity of the webhook.
        For more information please refer to [the consuming webhooks docs](https://docs.svix.com/consuming-webhooks/)."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}/secret",
            path_params={
                "endpoint_id": endpoint_id,
            },
        )
        return OperationalWebhookEndpointSecretOut.model_validate(response.json())

    async def rotate_secret(
        self,
        endpoint_id: str,
        operational_webhook_endpoint_secret_in: OperationalWebhookEndpointSecretIn,
        options: OperationalWebhookEndpointRotateSecretOptions = OperationalWebhookEndpointRotateSecretOptions(),
    ) -> None:
        """Rotates an operational webhook endpoint's signing secret.

        The previous secret will remain valid for the next 24 hours."""
        await self._request_asyncio(
            method="post",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}/secret/rotate",
            path_params={
                "endpoint_id": endpoint_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=operational_webhook_endpoint_secret_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )


class OperationalWebhookEndpoint(ApiBase):
    def list(
        self,
        options: OperationalWebhookEndpointListOptions = OperationalWebhookEndpointListOptions(),
    ) -> ListResponseOperationalWebhookEndpointOut:
        """List operational webhook endpoints."""
        response = self._request_sync(
            method="get",
            path="/api/v1/operational-webhook/endpoint",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseOperationalWebhookEndpointOut.model_validate(response.json())

    def create(
        self,
        operational_webhook_endpoint_in: OperationalWebhookEndpointIn,
        options: OperationalWebhookEndpointCreateOptions = OperationalWebhookEndpointCreateOptions(),
    ) -> OperationalWebhookEndpointOut:
        """Create an operational webhook endpoint."""
        response = self._request_sync(
            method="post",
            path="/api/v1/operational-webhook/endpoint",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=operational_webhook_endpoint_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return OperationalWebhookEndpointOut.model_validate(response.json())

    def get(self, endpoint_id: str) -> OperationalWebhookEndpointOut:
        """Get an operational webhook endpoint."""
        response = self._request_sync(
            method="get",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}",
            path_params={
                "endpoint_id": endpoint_id,
            },
        )
        return OperationalWebhookEndpointOut.model_validate(response.json())

    def update(
        self,
        endpoint_id: str,
        operational_webhook_endpoint_update: OperationalWebhookEndpointUpdate,
    ) -> OperationalWebhookEndpointOut:
        """Update an operational webhook endpoint."""
        response = self._request_sync(
            method="put",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}",
            path_params={
                "endpoint_id": endpoint_id,
            },
            json_body=operational_webhook_endpoint_update.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return OperationalWebhookEndpointOut.model_validate(response.json())

    def delete(self, endpoint_id: str) -> None:
        """Delete an operational webhook endpoint."""
        self._request_sync(
            method="delete",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}",
            path_params={
                "endpoint_id": endpoint_id,
            },
        )

    def get_headers(self, endpoint_id: str) -> OperationalWebhookEndpointHeadersOut:
        """Get the additional headers to be sent with the operational webhook."""
        response = self._request_sync(
            method="get",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}/headers",
            path_params={
                "endpoint_id": endpoint_id,
            },
        )
        return OperationalWebhookEndpointHeadersOut.model_validate(response.json())

    def update_headers(
        self,
        endpoint_id: str,
        operational_webhook_endpoint_headers_in: OperationalWebhookEndpointHeadersIn,
    ) -> None:
        """Set the additional headers to be sent with the operational webhook."""
        self._request_sync(
            method="put",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}/headers",
            path_params={
                "endpoint_id": endpoint_id,
            },
            json_body=operational_webhook_endpoint_headers_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )

    def get_secret(self, endpoint_id: str) -> OperationalWebhookEndpointSecretOut:
        """Get an operational webhook endpoint's signing secret.

        This is used to verify the authenticity of the webhook.
        For more information please refer to [the consuming webhooks docs](https://docs.svix.com/consuming-webhooks/)."""
        response = self._request_sync(
            method="get",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}/secret",
            path_params={
                "endpoint_id": endpoint_id,
            },
        )
        return OperationalWebhookEndpointSecretOut.model_validate(response.json())

    def rotate_secret(
        self,
        endpoint_id: str,
        operational_webhook_endpoint_secret_in: OperationalWebhookEndpointSecretIn,
        options: OperationalWebhookEndpointRotateSecretOptions = OperationalWebhookEndpointRotateSecretOptions(),
    ) -> None:
        """Rotates an operational webhook endpoint's signing secret.

        The previous secret will remain valid for the next 24 hours."""
        self._request_sync(
            method="post",
            path="/api/v1/operational-webhook/endpoint/{endpoint_id}/secret/rotate",
            path_params={
                "endpoint_id": endpoint_id,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=operational_webhook_endpoint_secret_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )



# this file is @generated
import typing as t
from datetime import datetime

from .common import BaseModel
from .message_status import MessageStatus


class MessageEndpointOut(BaseModel):
    channels: t.Optional[t.List[str]] = None
    """List of message channels this endpoint listens to (omit for all)."""

    created_at: datetime

    description: str
    """An example endpoint name."""

    disabled: t.Optional[bool] = None

    filter_types: t.Optional[t.List[str]] = None

    id: str
    """The ep's ID"""

    next_attempt: t.Optional[datetime] = None

    rate_limit: t.Optional[int] = None

    status: MessageStatus

    uid: t.Optional[str] = None
    """Optional unique identifier for the endpoint."""

    updated_at: datetime

    url: str

    version: int



# this file is @generated
import typing as t

from .application_in import ApplicationIn
from .common import BaseModel


class AppPortalAccessIn(BaseModel):
    application: t.Optional[ApplicationIn] = None
    """Optionally creates a new application while generating the access link.

    If the application id or uid that is used in the path already exists, this argument is ignored."""

    expiry: t.Optional[int] = None
    """How long the token will be valid for, in seconds.

    Valid values are between 1 hour and 7 days. The default is 7 days."""

    feature_flags: t.Optional[t.List[str]] = None
    """The set of feature flags the created token will have access to."""

    read_only: t.Optional[bool] = None
    """Whether the app portal should be in read-only mode."""



# this file is @generated
import typing as t
from datetime import datetime

from .common import BaseModel


class EventTypeOut(BaseModel):
    archived: t.Optional[bool] = None

    created_at: datetime

    deprecated: bool

    description: str

    feature_flag: t.Optional[str] = None

    group_name: t.Optional[str] = None
    """The event type group's name"""

    name: str
    """The event type's name"""

    schemas: t.Optional[t.Dict[str, t.Any]] = None
    """The schema for the event type for a specific version as a JSON schema."""

    updated_at: datetime



# this file is @generated
import typing as t

from .background_task_status import BackgroundTaskStatus
from .background_task_type import BackgroundTaskType
from .common import BaseModel


class BackgroundTaskOut(BaseModel):
    data: t.Dict[str, t.Any]

    id: str

    status: BackgroundTaskStatus

    task: BackgroundTaskType



# this file is @generated
import typing as t

from .background_task_status import BackgroundTaskStatus
from .background_task_type import BackgroundTaskType
from .common import BaseModel


class AppUsageStatsOut(BaseModel):
    id: str

    status: BackgroundTaskStatus

    task: BackgroundTaskType

    unresolved_app_ids: t.List[str]
    """Any app IDs or UIDs received in the request that weren't found.

    Stats will be produced for all the others."""



# this file is @generated
import typing as t
from datetime import datetime

from .common import BaseModel
from .message_attempt_trigger_type import MessageAttemptTriggerType
from .message_out import MessageOut
from .message_status import MessageStatus


class MessageAttemptOut(BaseModel):
    endpoint_id: str
    """The ep's ID"""

    id: str
    """The attempt's ID"""

    msg: t.Optional[MessageOut] = None

    msg_id: str
    """The msg's ID"""

    response: str

    response_duration_ms: int
    """Response duration in milliseconds."""

    response_status_code: int

    status: MessageStatus

    timestamp: datetime

    trigger_type: MessageAttemptTriggerType

    url: str



# This file is @generated
import typing as t
from dataclasses import dataclass

from .. import models
from ..models import (
    EventTypeImportOpenApiIn,
    EventTypeImportOpenApiOut,
    EventTypeIn,
    EventTypeOut,
    EventTypePatch,
    EventTypeUpdate,
    ListResponseEventTypeOut,
)
from .common import ApiBase, BaseOptions, serialize_params


@dataclass
class EventTypeListOptions(BaseOptions):
    limit: t.Optional[int] = None
    """Limit the number of returned items"""
    iterator: t.Optional[str] = None
    """The iterator returned from a prior invocation"""
    order: t.Optional[models.Ordering] = None
    """The sorting order of the returned items"""
    include_archived: t.Optional[bool] = None
    """When `true` archived (deleted but not expunged) items are included in the response."""
    with_content: t.Optional[bool] = None
    """When `true` the full item (including the schema) is included in the response."""

    def _query_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "limit": self.limit,
                "iterator": self.iterator,
                "order": self.order,
                "include_archived": self.include_archived,
                "with_content": self.with_content,
            }
        )


@dataclass
class EventTypeCreateOptions(BaseOptions):
    idempotency_key: t.Optional[str] = None

    def _header_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "idempotency-key": self.idempotency_key,
            }
        )


@dataclass
class EventTypeImportOpenapiOptions(BaseOptions):
    idempotency_key: t.Optional[str] = None

    def _header_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "idempotency-key": self.idempotency_key,
            }
        )


@dataclass
class EventTypeDeleteOptions(BaseOptions):
    expunge: t.Optional[bool] = None
    """By default event types are archived when "deleted". Passing this to `true` deletes them entirely."""

    def _query_params(self) -> t.Dict[str, str]:
        return serialize_params(
            {
                "expunge": self.expunge,
            }
        )


class EventTypeAsync(ApiBase):
    async def list(
        self, options: EventTypeListOptions = EventTypeListOptions()
    ) -> ListResponseEventTypeOut:
        """Return the list of event types."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/event-type",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseEventTypeOut.model_validate(response.json())

    async def create(
        self,
        event_type_in: EventTypeIn,
        options: EventTypeCreateOptions = EventTypeCreateOptions(),
    ) -> EventTypeOut:
        """Create new or unarchive existing event type.

        Unarchiving an event type will allow endpoints to filter on it and messages to be sent with it.
        Endpoints filtering on the event type before archival will continue to filter on it.
        This operation does not preserve the description and schemas."""
        response = await self._request_asyncio(
            method="post",
            path="/api/v1/event-type",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=event_type_in.model_dump_json(exclude_unset=True, by_alias=True),
        )
        return EventTypeOut.model_validate(response.json())

    async def import_openapi(
        self,
        event_type_import_open_api_in: EventTypeImportOpenApiIn,
        options: EventTypeImportOpenapiOptions = EventTypeImportOpenapiOptions(),
    ) -> EventTypeImportOpenApiOut:
        """Given an OpenAPI spec, create new or update existing event types.
        If an existing `archived` event type is updated, it will be unarchived.

        The importer will convert all webhooks found in the either the `webhooks` or `x-webhooks`
        top-level."""
        response = await self._request_asyncio(
            method="post",
            path="/api/v1/event-type/import/openapi",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=event_type_import_open_api_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return EventTypeImportOpenApiOut.model_validate(response.json())

    async def get(self, event_type_name: str) -> EventTypeOut:
        """Get an event type."""
        response = await self._request_asyncio(
            method="get",
            path="/api/v1/event-type/{event_type_name}",
            path_params={
                "event_type_name": event_type_name,
            },
        )
        return EventTypeOut.model_validate(response.json())

    async def update(
        self, event_type_name: str, event_type_update: EventTypeUpdate
    ) -> EventTypeOut:
        """Update an event type."""
        response = await self._request_asyncio(
            method="put",
            path="/api/v1/event-type/{event_type_name}",
            path_params={
                "event_type_name": event_type_name,
            },
            json_body=event_type_update.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return EventTypeOut.model_validate(response.json())

    async def delete(
        self,
        event_type_name: str,
        options: EventTypeDeleteOptions = EventTypeDeleteOptions(),
    ) -> None:
        """Archive an event type.

        Endpoints already configured to filter on an event type will continue to do so after archival.
        However, new messages can not be sent with it and endpoints can not filter on it.
        An event type can be unarchived with the
        [create operation](#operation/create_event_type_api_v1_event_type__post)."""
        await self._request_asyncio(
            method="delete",
            path="/api/v1/event-type/{event_type_name}",
            path_params={
                "event_type_name": event_type_name,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )

    async def patch(
        self, event_type_name: str, event_type_patch: EventTypePatch
    ) -> EventTypeOut:
        """Partially update an event type."""
        response = await self._request_asyncio(
            method="patch",
            path="/api/v1/event-type/{event_type_name}",
            path_params={
                "event_type_name": event_type_name,
            },
            json_body=event_type_patch.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return EventTypeOut.model_validate(response.json())


class EventType(ApiBase):
    def list(
        self, options: EventTypeListOptions = EventTypeListOptions()
    ) -> ListResponseEventTypeOut:
        """Return the list of event types."""
        response = self._request_sync(
            method="get",
            path="/api/v1/event-type",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
        )
        return ListResponseEventTypeOut.model_validate(response.json())

    def create(
        self,
        event_type_in: EventTypeIn,
        options: EventTypeCreateOptions = EventTypeCreateOptions(),
    ) -> EventTypeOut:
        """Create new or unarchive existing event type.

        Unarchiving an event type will allow endpoints to filter on it and messages to be sent with it.
        Endpoints filtering on the event type before archival will continue to filter on it.
        This operation does not preserve the description and schemas."""
        response = self._request_sync(
            method="post",
            path="/api/v1/event-type",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=event_type_in.model_dump_json(exclude_unset=True, by_alias=True),
        )
        return EventTypeOut.model_validate(response.json())

    def import_openapi(
        self,
        event_type_import_open_api_in: EventTypeImportOpenApiIn,
        options: EventTypeImportOpenapiOptions = EventTypeImportOpenapiOptions(),
    ) -> EventTypeImportOpenApiOut:
        """Given an OpenAPI spec, create new or update existing event types.
        If an existing `archived` event type is updated, it will be unarchived.

        The importer will convert all webhooks found in the either the `webhooks` or `x-webhooks`
        top-level."""
        response = self._request_sync(
            method="post",
            path="/api/v1/event-type/import/openapi",
            path_params={},
            query_params=options._query_params(),
            header_params=options._header_params(),
            json_body=event_type_import_open_api_in.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return EventTypeImportOpenApiOut.model_validate(response.json())

    def get(self, event_type_name: str) -> EventTypeOut:
        """Get an event type."""
        response = self._request_sync(
            method="get",
            path="/api/v1/event-type/{event_type_name}",
            path_params={
                "event_type_name": event_type_name,
            },
        )
        return EventTypeOut.model_validate(response.json())

    def update(
        self, event_type_name: str, event_type_update: EventTypeUpdate
    ) -> EventTypeOut:
        """Update an event type."""
        response = self._request_sync(
            method="put",
            path="/api/v1/event-type/{event_type_name}",
            path_params={
                "event_type_name": event_type_name,
            },
            json_body=event_type_update.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return EventTypeOut.model_validate(response.json())

    def delete(
        self,
        event_type_name: str,
        options: EventTypeDeleteOptions = EventTypeDeleteOptions(),
    ) -> None:
        """Archive an event type.

        Endpoints already configured to filter on an event type will continue to do so after archival.
        However, new messages can not be sent with it and endpoints can not filter on it.
        An event type can be unarchived with the
        [create operation](#operation/create_event_type_api_v1_event_type__post)."""
        self._request_sync(
            method="delete",
            path="/api/v1/event-type/{event_type_name}",
            path_params={
                "event_type_name": event_type_name,
            },
            query_params=options._query_params(),
            header_params=options._header_params(),
        )

    def patch(
        self, event_type_name: str, event_type_patch: EventTypePatch
    ) -> EventTypeOut:
        """Partially update an event type."""
        response = self._request_sync(
            method="patch",
            path="/api/v1/event-type/{event_type_name}",
            path_params={
                "event_type_name": event_type_name,
            },
            json_body=event_type_patch.model_dump_json(
                exclude_unset=True, by_alias=True
            ),
        )
        return EventTypeOut.model_validate(response.json())



# this file is @generated
from enum import IntEnum


class MessageStatus(IntEnum):
    """The sending status of the message:
    - Success = 0
    - Pending = 1
    - Fail = 2
    - Sending = 3"""

    SUCCESS = 0
    PENDING = 1
    FAIL = 2
    SENDING = 3

    def __str__(self) -> str:
        return str(self.value)



# this file is @generated
from datetime import datetime

from .common import BaseModel


class IntegrationOut(BaseModel):
    created_at: datetime

    id: str
    """The integ's ID"""

    name: str

    updated_at: datetime



# this file is @generated
import typing as t
from datetime import datetime

from .common import BaseModel
from .transformation_template_kind import TransformationTemplateKind


class TemplateOut(BaseModel):
    created_at: datetime

    description: str

    feature_flag: t.Optional[str] = None

    filter_types: t.Optional[t.List[str]] = None

    id: str

    instructions: str

    instructions_link: t.Optional[str] = None

    kind: TransformationTemplateKind

    logo: str

    name: str

    org_id: str

    transformation: str

    updated_at: datetime
